import { MetadataApiDeploy, MetadataApiDeployOptions, MetadataApiRetrieve, MetadataApiRetrieveOptions } from '../client';
import { MetadataComponent } from '../common';
import { RegistryAccess, SourceComponent } from '../metadata-registry';
import { FromSourceOptions, FromManifestOptions, PackageManifestObject, ResolveOptions } from './types';
import { ComponentLike } from '../common/types';
import { LazyCollection } from './lazyCollection';
export declare type DeploySetOptions = Omit<MetadataApiDeployOptions, 'components'>;
export declare type RetrieveSetOptions = Omit<MetadataApiRetrieveOptions, 'components'>;
export declare class ComponentSet extends LazyCollection<MetadataComponent> {
    static readonly WILDCARD = "*";
    private static readonly KEY_DELIMITER;
    apiVersion: string;
    private registry;
    private components;
    constructor(components?: Iterable<ComponentLike>, registry?: RegistryAccess);
    /**
     * Create a set by resolving components from source.
     *
     * @param fsPath Path to resolve components from
     * @param options
     */
    static fromSource(fsPath: string, options?: FromSourceOptions): ComponentSet;
    /**
     * Create a set by reading a manifest file in xml format. Optionally, specify a file path
     * with the `resolve` option to resolve source files for the components.
     *
     * ```
     * WorkingSet.fromManifestFile('/path/to/package.xml', {
     *  resolve: '/path/to/force-app'
     * });
     * ```
     *
     * @param fsPath Path to xml file
     * @param options
     */
    static fromManifestFile(fsPath: string, options?: FromManifestOptions): Promise<ComponentSet>;
    private static getComponentsFromManifestObject;
    /**
     * Constructs a deploy operation using the components in the set. There must be at least
     * one source-backed component in the set to create an operation.
     *
     * @param options
     */
    deploy(options: DeploySetOptions): MetadataApiDeploy;
    /**
     * Constructs a retrieve operation using the components in the set.
     *
     * @param options
     */
    retrieve(options: RetrieveSetOptions): MetadataApiRetrieve;
    /**
     * Get an object representation of a package manifest based on the set components.
     */
    getObject(): PackageManifestObject;
    /**
     * Resolve source backed components and add them to the set.
     *
     * @param fsPath: File path to resolve
     * @param options
     */
    resolveSourceComponents(fsPath: string, options?: ResolveOptions): ComponentSet;
    /**
     * Create a manifest in xml format (package.xml) based on the set components.
     *
     * @param indentation Number of spaces to indent lines by.
     */
    getPackageXml(indentation?: number): string;
    getSourceComponents(member?: ComponentLike): LazyCollection<SourceComponent>;
    add(component: ComponentLike): void;
    has(component: ComponentLike): boolean;
    [Symbol.iterator](): Iterator<MetadataComponent>;
    get size(): number;
    private sourceKey;
    private simpleKey;
}
